@@ -50,6 +50,7 @@
 #include "gedit-view.h"
 #include "gedit-utils.h"
 #include "gedit-plugins-engine.h"
+#include "gnome-recent-view-bonobo.h"
 
 #include <bonobo/bonobo-ui-util.h>
 #include <bonobo/bonobo-control.h>
@@ -216,13 +217,49 @@ gedit_mdi_new (void)
 	return mdi;
 }
 
+/* Computes a unique ID string for use as the window role */
+/* Taken from EOG */
+
+static char *
+gen_role (void)
+{
+        char *ret;
+	static char *hostname;
+	time_t t;
+	static int serial;
+
+	t = time (NULL);
+
+	if (!hostname) {
+		static char buffer [512];
+
+		if ((gethostname (buffer, sizeof (buffer) - 1) == 0) &&
+		    (buffer [0] != 0))
+			hostname = buffer;
+		else
+			hostname = "localhost";
+	}
+
+	ret = g_strdup_printf ("gedit-window-%d-%d-%d-%ld-%d@%s",
+			       getpid (),
+			       getgid (),
+			       getppid (),
+			       (long) t,
+			       serial++,
+			       hostname);
+
+	return ret;
+}
+
 static void
 gedit_mdi_app_created_handler (BonoboMDI *mdi, BonoboWindow *win)
 {
 	GtkWidget *widget;
 	BonoboControl *control;
 	BonoboUIComponent *ui_component;
-	GeditRecent *recent;
+	GnomeRecentView *view;
+	GnomeRecentModel *model;
+	gchar *role;
 
 	static GtkTargetEntry drag_types[] =
 	{
@@ -302,9 +339,6 @@ gedit_mdi_app_created_handler (BonoboMDI *mdi, BonoboWindow *win)
 	bonobo_ui_component_add_listener (ui_component, "ToolbarIconText", 
 			(BonoboUIListenerFn)gedit_mdi_view_menu_item_toggled_handler, 
 			(gpointer)win);
-	bonobo_ui_component_add_listener (ui_component, "ToolbarTooltips", 
-			(BonoboUIListenerFn)gedit_mdi_view_menu_item_toggled_handler, 
-			(gpointer)win);
 
 	bonobo_ui_component_add_listener (ui_component, "StatusBarCursorPosition", 
 			(BonoboUIListenerFn)gedit_mdi_view_menu_item_toggled_handler, 
@@ -314,14 +348,14 @@ gedit_mdi_app_created_handler (BonoboMDI *mdi, BonoboWindow *win)
 			(gpointer)win);
 
 
-	/* add a GeditRecent object */
-	recent = gedit_recent_new_with_ui_component ("gedit",
-						     gedit_settings->max_recents,
-						     ui_component,
-						     "/menu/File/Recents");
-	g_signal_connect (G_OBJECT (recent), "activate",
+	/* add a GeditRecentView object */
+	model = gedit_recent_get_model ();
+	view = GNOME_RECENT_VIEW (gnome_recent_view_bonobo_new (ui_component, "/menu/File/Recents"));
+	gnome_recent_view_set_model (view, model);
+	
+	g_signal_connect (G_OBJECT (view), "activate",
 			  G_CALLBACK (gedit_file_open_recent), NULL);
-	g_object_set_data (G_OBJECT (win), RECENT_KEY, recent);
+	g_object_set_data (G_OBJECT (win), RECENT_KEY, view);
 
 	/* Set the window prefs. */
 	gtk_window_set_default_size (GTK_WINDOW (win), 
@@ -334,6 +368,11 @@ gedit_mdi_app_created_handler (BonoboMDI *mdi, BonoboWindow *win)
 	
 	/* Add the plugins menus */
 	gedit_plugins_engine_update_plugins_ui (win, TRUE);
+
+	/* Set window role */
+	role = gen_role ();
+	gtk_window_set_role (GTK_WINDOW (win), role);
+	g_free (role);
 }
 
 static void
@@ -393,15 +432,6 @@ gedit_mdi_view_menu_item_toggled_handler (
 		return;
 	}
 
-	if ((strcmp (path, "ToolbarTooltips") == 0) &&
-	    (s != gedit_settings->toolbar_view_tooltips))
-	{
-		gedit_settings->toolbar_view_tooltips = s;
-		gedit_mdi_set_app_toolbar_style (win);
-
-		return;
-	}
-
 	if ((strcmp (path, "StatusBarCursorPosition") == 0) &&
 	    (s != gedit_settings->statusbar_view_cursor_position))
 	{
@@ -457,8 +487,6 @@ static void
 gedit_mdi_set_app_toolbar_style (BonoboWindow *win)
 {
 	BonoboUIComponent *ui_component;
-	GConfClient *client;
-	gchar *style = NULL;
 
 	gedit_debug (DEBUG_MDI, "");
 	
@@ -483,9 +511,6 @@ gedit_mdi_set_app_toolbar_style (BonoboWindow *win)
 	gedit_menus_set_verb_sensitive (ui_component, 
 				        "/commands/ToolbarIconText",
 				        gedit_settings->toolbar_visible);
-	gedit_menus_set_verb_sensitive (ui_component, 
-				        "/commands/ToolbarTooltips",
-				        gedit_settings->toolbar_visible);
 
 	gedit_menus_set_verb_state (ui_component, 
 				    "/commands/ToolbarSystem",
@@ -499,37 +524,13 @@ gedit_mdi_set_app_toolbar_style (BonoboWindow *win)
 				    "/commands/ToolbarIconText",
 				    gedit_settings->toolbar_buttons_style == GEDIT_TOOLBAR_ICONS_AND_TEXT);
 
-	gedit_menus_set_verb_state (ui_component, 
-				    "/commands/ToolbarTooltips",
-				    gedit_settings->toolbar_view_tooltips);
-
-	
-	/* Actually update toolbar style */
-	bonobo_ui_component_set_prop (
-		ui_component, "/Toolbar",
-		"tips", gedit_settings->toolbar_view_tooltips ? "1" : "0",
-		NULL);
-	
 	switch (gedit_settings->toolbar_buttons_style)
 	{
 		case GEDIT_TOOLBAR_SYSTEM:
-						
-			client = gconf_client_get_default ();
-			if (client == NULL) 
-				goto error;
 
-			style = gconf_client_get_string (client, 
-					"/desktop/gnome/interface/toolbar_style", NULL);
-
-			g_object_unref (G_OBJECT (client));
-			
-			if (style != NULL)
-			{
-				bonobo_ui_component_set_prop (
-					ui_component, "/Toolbar", "look", style, NULL);
-			
-				g_free (style);
-			}
+			gedit_debug (DEBUG_MDI, "GEDIT: SYSTEM");
+			bonobo_ui_component_set_prop (
+				ui_component, "/Toolbar", "look", "system", NULL);
 
 			break;
 			
@@ -1111,13 +1112,13 @@ gedit_mdi_update_ui_according_to_preferences (GeditMDI *mdi)
 	g_free (font);
 }
 
-GeditRecent*
-gedit_mdi_get_recent_from_window (BonoboWindow* win)
+GnomeRecentView *
+gedit_mdi_get_recent_view_from_window (BonoboWindow* win)
 {
 	gpointer r;
 	gedit_debug (DEBUG_MDI, "");
 
 	r = g_object_get_data (G_OBJECT (win), RECENT_KEY);
 	
-	return (r != NULL) ? GEDIT_RECENT (r) : NULL;
+	return (r != NULL) ? GNOME_RECENT_VIEW (r) : NULL;
 }
